@@ -956,7 +956,7 @@ void AnnotationDocument::paint(QPainter *painter, const QRectF &viewPort, qreal
             // More High quality scale down
             auto scaledImg = img.image.scaled(zoomSize(img.image.size(), zoomFactor).toSize(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
             scaledImg.setDevicePixelRatio(img.image.devicePixelRatio());
-            painter->drawImage(zoomPoint(img.rect.topLeft() - viewPort.topLeft() * img.image.devicePixelRatio(), zoomFactor).toPoint(), scaledImg);
+            painter->drawImage(zoomPoint((img.rect.topLeft() - viewPort.topLeft()) * img.image.devicePixelRatio(), zoomFactor).toPoint(), scaledImg);
         }
     }
 
@@ -1159,6 +1159,15 @@ EditAction *AnnotationDocument::actionAtPoint(const QPointF &point) const
     return nullptr;
 }
 
+QRectF AnnotationDocument::visualGeometryAtPoint(const QPointF &point) const
+{
+    auto action = actionAtPoint(point);
+    if (!action) {
+        return {};
+    }
+    return action->visualGeometry();
+}
+
 void AnnotationDocument::undo()
 {
     if (m_undoStack.isEmpty()) {
